summaryrefslogtreecommitdiffstats
path: root/src/common
diff options
context:
space:
mode:
authorErik Schilling <ablu.erikschilling@googlemail.com>2013-04-13 12:32:22 +0200
committerErik Schilling <ablu.erikschilling@googlemail.com>2013-05-08 14:02:50 +0200
commit708896008ad8ea391d542ce37b9871318a84fb97 (patch)
tree30c862cb18d354f879ffb0b426d5ff133d2bde3b /src/common
parente2b6a4efe72333ab0e0761f4e9e8ce9eb29a5335 (diff)
downloadmanaserv-708896008ad8ea391d542ce37b9871318a84fb97.tar.gz
manaserv-708896008ad8ea391d542ce37b9871318a84fb97.tar.xz
manaserv-708896008ad8ea391d542ce37b9871318a84fb97.zip
[Abilities] Renamed specials to abilities
Diffstat (limited to 'src/common')
-rw-r--r--src/common/manaserv_protocol.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/common/manaserv_protocol.h b/src/common/manaserv_protocol.h
index 2a1c9c1..5649999 100644
--- a/src/common/manaserv_protocol.h
+++ b/src/common/manaserv_protocol.h
@@ -30,7 +30,7 @@ namespace ManaServ {
enum {
PROTOCOL_VERSION = 3,
- SUPPORTED_DB_VERSION = 21
+ SUPPORTED_DB_VERSION = 22
};
/**
@@ -145,9 +145,9 @@ enum {
GPMSG_ITEMS = 0x0281, // { W item id, W*2 position }*
PGMSG_ATTACK = 0x0290, // W being id
GPMSG_BEING_ATTACK = 0x0291, // W being id, B direction, B attack Id
- PGMSG_USE_SPECIAL_ON_BEING = 0x0292, // B specialID, W being id
- GPMSG_SPECIAL_STATUS = 0x0293, // { B specialID, D current, D max, D recharge }
- PGMSG_USE_SPECIAL_ON_POINT = 0x0294, // B specialID, W*2 position
+ PGMSG_USE_ABILITY_ON_BEING = 0x0292, // B abilityID, W being id
+ GPMSG_ABILITY_STATUS = 0x0293, // { B abilityID, D current, D max, D recharge }
+ PGMSG_USE_ABILITY_ON_POINT = 0x0294, // B abilityID, W*2 position
PGMSG_SAY = 0x02A0, // S text
GPMSG_SAY = 0x02A1, // W being id, S text
GPMSG_NPC_CHOICE = 0x02B0, // W being id, { S text }*